@@ -1,17 +1,16 @@
 """SOP policy class using PyTorch."""
-import collections
-
 import torch
 import torch.nn as nn
 from ray.rllib.utils import override
 
-import raylab.policy as raypi
 from raylab.losses import ClippedDoubleQLearning
 from raylab.losses import DeterministicPolicyGradient
+from raylab.policy import TargetNetworksMixin
+from raylab.policy import TorchPolicy
 from raylab.pytorch.optim import build_optimizer
 
 
-class SOPTorchPolicy(raypi.TargetNetworksMixin, raypi.TorchPolicy):
+class SOPTorchPolicy(TargetNetworksMixin, TorchPolicy):
     """Streamlined Off-Policy policy in PyTorch to use with RLlib."""
 
     # pylint: disable=abstract-method
@@ -29,7 +28,7 @@ class SOPTorchPolicy(raypi.TargetNetworksMixin, raypi.TorchPolicy):
         )
 
     @staticmethod
-    @override(raypi.TorchPolicy)
+    @override(TorchPolicy)
     def get_default_config():
         """Return the default configuration for SOP."""
         # pylint: disable=cyclic-import
@@ -37,7 +36,7 @@ class SOPTorchPolicy(raypi.TargetNetworksMixin, raypi.TorchPolicy):
 
         return DEFAULT_CONFIG
 
-    @override(raypi.TorchPolicy)
+    @override(TorchPolicy)
     def make_module(self, obs_space, action_space, config):
         module_config = config["module"]
         module_config.setdefault("critic", {})
@@ -50,37 +49,39 @@ class SOPTorchPolicy(raypi.TargetNetworksMixin, raypi.TorchPolicy):
         # pylint:disable=no-member
         return super().make_module(obs_space, action_space, config)
 
-    @override(raypi.TorchPolicy)
-    def make_optimizer(self):
+    @override(TorchPolicy)
+    def make_optimizers(self):
         config = self.config["torch_optimizer"]
-        components = ["actor", "critics"]
+        components = "actor critics".split()
 
-        optims = {k: build_optimizer(self.module[k], config[k]) for k in components}
-        return collections.namedtuple("OptimizerCollection", components)(**optims)
+        return {
+            name: build_optimizer(self.module[name], config[name])
+            for name in components
+        }
 
-    @override(raypi.TorchPolicy)
+    @override(TorchPolicy)
     def learn_on_batch(self, samples):
-        batch_tensors = self._lazy_tensor_dict(samples)
+        batch_tensors = self.lazy_tensor_dict(samples)
 
         info = {}
         info.update(self._update_critic(batch_tensors))
         info.update(self._update_policy(batch_tensors))
 
         self.update_targets("critics", "target_critics")
-        return self._learner_stats(info)
+        return info
 
     def _update_critic(self, batch_tensors):
-        with self.optimizer.critics.optimize():
-            critic_loss, info = self.loss_critic(batch_tensors)
-            critic_loss.backward()
+        with self.optimizers.optimize("critics"):
+            loss, info = self.loss_critic(batch_tensors)
+            loss.backward()
 
         info.update(self.extra_grad_info("critics"))
         return info
 
     def _update_policy(self, batch_tensors):
-        with self.optimizer.actor.optimize():
-            policy_loss, info = self.loss_actor(batch_tensors)
-            policy_loss.backward()
+        with self.optimizers.optimize("actor"):
+            loss, info = self.loss_actor(batch_tensors)
+            loss.backward()
 
         info.update(self.extra_grad_info("actor"))
         return info
