@@ -116,7 +116,12 @@ class ModelTrainingMixin:
         spec = self.model_training_spec
         snapshots = self._build_snapshots()
         dataloader = self._build_dataloader(train_samples, spec.dataloader)
-        eval_tensors = self.lazy_tensor_dict(eval_samples) if eval_samples else None
+        eval_tensors = None
+        if eval_samples:
+            eval_tensors = {
+                k: self.convert_to_tensor(eval_samples[k])
+                for k in self.loss_model.batch_keys
+            }
 
         info, snapshots = self._train_model_epochs(
             dataloader, snapshots, eval_tensors, spec
@@ -136,10 +141,11 @@ class ModelTrainingMixin:
     def _build_dataloader(
         self, train_samples: SampleBatch, spec: DataloaderSpec
     ) -> DataLoader:
-        train_tensors = self.lazy_tensor_dict(train_samples)
-        dataset = TensorDictDataset(
-            {k: train_tensors[k] for k in self.loss_model.batch_keys}
-        )
+        train_tensors = {
+            k: self.convert_to_tensor(train_samples[k])
+            for k in self.loss_model.batch_keys
+        }
+        dataset = TensorDictDataset(train_tensors)
         sampler = RandomSampler(dataset, replacement=spec.replacement)
         return DataLoader(dataset, sampler=sampler, batch_size=spec.batch_size)
 
