@@ -13,11 +13,21 @@ def teardown_module():
     ray.shutdown()
 
 
+@pytest.fixture(
+    scope="module",
+    params=(True, False),
+    ids=(f"CompilePolicy({b})" for b in (True, False)),
+)
+def compile_policy(request):
+    return request.param
+
+
 @pytest.fixture(scope="module")
-def trainer(trainer_cls):
+def trainer(trainer_cls, compile_policy):
     return trainer_cls(
         env=MockEnv,
         config={
+            "compile_policy": compile_policy,
             "num_workers": 0,
             "rollout_fragment_length": 10,
             "evaluation_config": {"explore": False},
